@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-09'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [str => {
     summary => 'Latin letter, i.e. A-Z or a-z',
@@ -37,7 +37,7 @@ Sah::Schema::latin_letter - Latin letter, i.e. A-Z or a-z
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::latin_letter (from Perl distribution Sah-Schemas-Str), released on 2022-07-09.
+This document describes version 0.011 of Sah::Schema::latin_letter (from Perl distribution Sah-Schemas-Str), released on 2022-07-09.
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = 1;
+ $data = ";";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A[A-Za-z]\\z)"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -88,8 +88,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","A"]
  
  # a sample invalid data
- $data = 1;
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Za-z]\\z)",1]
+ $data = ";";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Za-z]\\z)",";"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
